@@ -17,7 +17,7 @@ sub enter_scope
     @{$self}{qw/OLD_X OLD_Y/} = map { $context->get($self, $_) } qw(X Y);
 
     $context->{X} = 0;
-    $context->{Y} = $context->resolve($self, 'FOOTER_HEIGHT');
+    $context->{Y} = $context->get($self, 'FOOTER_HEIGHT');
 
     return $self->SUPER::enter_scope($context);
 }
@@ -73,7 +73,7 @@ None
 
 =head1 AUTHOR
 
-Rob Kinyon (rkinyon@columbus.rr.com)
+Rob Kinyon (rob.kinyon@gmail.com)
 
 =head1 SEE ALSO
 
