@@ -85,17 +85,14 @@ None
 
 =head1 USAGE
 
-<row h="8">
-
-  <textbox w="50%" justify="right" text"Hello,"/>
-
-  <textbox w="50%" justify="left" text"World"/>
-
-</row>
+  <row h="8">
+    <textbox w="50%" justify="right" text"Hello,"/>
+    <textbox w="50%" justify="left" text"World"/>
+  </row>
 
 =head1 AUTHOR
 
-Rob Kinyon (rkinyon@columbus.rr.com)
+Rob Kinyon (rob.kinyon@gmail.com)
 
 =head1 SEE ALSO
 
