@@ -92,7 +92,7 @@ URL attribute should be added to various nodes, such as IMAGE, TEXTBOX, and ROW.
 
 =head1 AUTHOR
 
-Rob Kinyon (rkinyon@columbus.rr.com)
+Rob Kinyon (rob.kinyon@gmail.com)
 
 =head1 SEE ALSO
 
