@@ -49,31 +49,3 @@ UNI_NO         $t .= $val;
 
 1;
 __END__
-
-=head1 NAME
-
-PDF::Template::TextObject
-
-=head1 PURPOSE
-
-=head1 NODE NAME
-
-=head1 INHERITANCE
-
-=head1 ATTRIBUTES
-
-=head1 CHILDREN
-
-=head1 AFFECTS
-
-=head1 DEPENDENCIES
-
-=head1 USAGE
-
-=head1 AUTHOR
-
-Rob Kinyon (rkinyon@columbus.rr.com)
-
-=head1 SEE ALSO
-
-=cut
